/*
 * Copyright (C) 2005 TopCoder Inc., All Rights Reserved.
 *
 * TCS File Statistics 1.0
 */
package com.topcoder.file.statistics;

import java.io.File;
import java.io.IOException;

/**
 * <summary> FileMatcher defines the contract to match a certain file (in order for an attaching FileProcessor to
 * process the file). </summary>
 *
 * <contract-constructor> All implementation should have a constructor with a Property as an argument in order to
 * reflect from configuration file. This requirement can be dropped if it's not necessary to use this way.
 * </contract-constructor>
 *
 * <thread-safety> Implementations are advised to be stateless and thread-safe. But it's not a requirement.
 * </thread-safety>
 *
 * @author WishingBone, TCSDEVELOPER
 * @version 1.0
 */
public interface FileMatcher {

    /**
     * <summary> This is used to determine if the file can/will be processed by the processor that this matcher is
     * associated with. </summary>
     *
     * @return whether the file matches
     * @param file the file to match
     *
     * @throws NullPointerException if file is null
     * @throws IOException if io operation fails
     * @throws FileMatchingException if error occurs
     */
    public boolean match(File file) throws IOException, FileMatchingException;
}
