/*
 * Copyright (C) 2005 TopCoder Inc., All Rights Reserved.
 *
 * TCS File Statistics 1.0 (Unit Test)
 */
package com.topcoder.file.statistics;

import junit.framework.TestCase;

/**
 * <p>Unit test case for Metric class.</p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class MetricTests extends TestCase {

    /** A test name string. */
    private static final String NAME = "name";

    /** A test display name string. */
    private static final String DISPLAY_NAME = "test display name";

    /** A test description string. */
    private static final String DESCRIPTION = "test description";

    /** A metric used in tests. */
    private static final Metric METRIC = new Metric(NAME, DISPLAY_NAME, DESCRIPTION);

    /** Another metric used in tests. Same display name and description, but different name. */
    private static final Metric METRIC_2 = new Metric("name2", DISPLAY_NAME, DESCRIPTION);

    /** Yet another metric used in tests. Same name as the first one. */
    private static final Metric METRIC_3 = new Metric(NAME, "test display name 3", "test description 3");

    /**
     * Creation test for Metric with valid arguments.
     */
    public void testMetric1() {
        Metric metric = new Metric(NAME, DISPLAY_NAME, DESCRIPTION);
        assertSame("name was not propagated correctly", metric.getName(), NAME);
        assertSame("display name was not propagated correctly", metric.getDisplayName(), DISPLAY_NAME);
        assertSame("description was not propagated correctly", metric.getDescription(), DESCRIPTION);
    }

    /**
     * Creation test for Metric with some null argument. NullPointerException should be thrown.
     */
    public void testMetric2() {
        try {
            new Metric(null, DISPLAY_NAME, DESCRIPTION);
            fail("NullPointerException should be thrown.");
        } catch (NullPointerException e) {
            // ok
        }

        try {
            new Metric(NAME, null, DESCRIPTION);
            fail("NullPointerException should be thrown.");
        } catch (NullPointerException e) {
            // ok
        }

        try {
            new Metric(NAME, DISPLAY_NAME, null);
            fail("NullPointerException should be thrown.");
        } catch (NullPointerException e) {
            // ok
        }
    }

    /**
     * Creation test for Metric with some empty string argument. IllegalArgumentException should be thrown.
     */
    public void testMetric3() {
        try {
            new Metric(" ", DISPLAY_NAME, DESCRIPTION);
            fail("IllegalArgumentException should be thrown.");
        } catch (IllegalArgumentException e) {
            // ok
        }

        try {
            new Metric(NAME, " ", DESCRIPTION);
            fail("IllegalArgumentException should be thrown.");
        } catch (IllegalArgumentException e) {
            // ok
        }

        try {
            new Metric(NAME, DISPLAY_NAME, " ");
            fail("IllegalArgumentException should be thrown.");
        } catch (IllegalArgumentException e) {
            // ok
        }
    }

    /**
     * Tests getName getter method.
     */
    public void testGetName() {
        assertEquals("name was not retrieved properly", METRIC.getName(), NAME);
    }

    /**
     * Tests getDisplayName getter method.
     */
    public void testGetDisplayName() {
        assertEquals("display name was not retrieved properly", METRIC.getDisplayName(), DISPLAY_NAME);
    }

    /**
     * Tests getDescription getter method.
     */
    public void testGetDescription() {
        assertEquals("description name was not retrieved properly", METRIC.getDescription(), DESCRIPTION);
    }

    /**
     * Tests equals method. Only metrics with equal name should be equal.
     */
    public void testEquals() {
        assertFalse("metric shoud not equal null", METRIC.equals(null));
        assertFalse("metric shoud not equal non-metric object", METRIC.equals(new Object()));
        assertFalse("metric shoud not equal metric with different name", METRIC.equals(METRIC_2));
        assertTrue("metric shoud equal metric with same name", METRIC.equals(METRIC_3));
        assertTrue("metric shoud equal itself", METRIC.equals(METRIC));
    }

    /**
     * Tests hashCode() method. Metrics with equal names should have same hash codes.
     */
    public void testHashCode() {
        assertEquals("metrics with equal names should have equal hashcodes", METRIC.hashCode(), METRIC_3
                .hashCode());
        assertFalse("metrics with different names are likely to have different hashcodes",
                METRIC.hashCode() == METRIC_2.hashCode());
    }

}
