/*
 * Copyright (C) 2005 TopCoder Inc., All Rights Reserved.
 *
 * TCS File Statistics 1.0 (Unit Test)
 */
package com.topcoder.file.statistics.matcher;

import java.io.File;
import java.io.IOException;

import junit.framework.TestCase;

import com.topcoder.file.statistics.FileMatchingException;
import com.topcoder.file.type.FileType;

/**
 * <p>Unit test case for FileTypeMatcher class.</p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class FileTypeMatcherTests extends TestCase {

    /** A concrete subclass of FileTypeMatcher that accepts only PDF files. */
    private static final class MyFileTypeMatcher extends FileTypeMatcher {

        /**
         * Returns whether the file type matches.
         *
         * @return whether the file matches
         * @param type the file type to match
         */
        protected boolean match(FileType type) {
            return "application/pdf".equals(type.getMime());
        }

    }

    /** The matcher instance that is tested. */
    private static final MyFileTypeMatcher MATCHER = new MyFileTypeMatcher();

    /**
     * Creation test for MyFileTypeMatcher() default constructor.
     */
    public void testMyFileTypeMatcherString1() {
        new MyFileTypeMatcher();
        // nothing to check
    }

    /**
     * Tests match(File) method with null argument. NullPointerException should be thrown.
     *
     * @throws FileMatchingException to JUnit
     * @throws IOException to JUnit
     */
    public void testMatchFile1() throws FileMatchingException, IOException {
        try {
            MATCHER.match((File) null);
            fail("NullPointerException should be thrown.");
        } catch (NullPointerException e) {
            // ok
        }
    }

    /**
     * Tests match(File) method with valid arguments. Only the files which type name is contained in MimeMatcher's
     * types list should be matched.
     *
     * @throws IOException to JUnit
     * @throws FileMatchingException to JUnit
     */
    public void testMatchFile2() throws FileMatchingException, IOException {
        assertTrue("pdf file should be matched", MATCHER.match(new File("test_files/a/reqspec.pdf")));
        assertFalse("zip file should not be matched", MATCHER.match(new File("test_files/a/p.zip")));
        assertFalse("unrecognized type file should not be matched", MATCHER.match(new File("test_files/a/p.txt")));
    }

    /**
     * Tests match(File) method with invalid file argument. IOException should be thrown.
     *
     * @throws FileMatchingException to JUnit
     */
    public void testMatchFile3() throws FileMatchingException {
        // directory
        try {
            MATCHER.match(new File("test_files/p/"));
            fail("IOException should be thrown.");
        } catch (IOException e) {
            // ok
        }
        // not existing
        try {
            MATCHER.match(new File("test_files/not_exists"));
            fail("IOException should be thrown.");
        } catch (IOException e) {
            // ok
        }
    }

}
