/*
 * Copyright (C) 2005 TopCoder Inc., All Rights Reserved.
 *
 * TCS File Statistics 1.0
 */
package com.topcoder.file.statistics;

import java.util.List;
import java.util.Map;

/**
 * <summary> ArgumentHandler is the interface added since version 2.0b to represent an entity that could
 * potentially require arguments from the command line. Current the supported entities (that can potentially use
 * arguments support) are FileStatistics, FileProcessor, FileMatcher and StatsReporting. The procedure works in two
 * phases. In the first step the handler proposes the options that it supports to the command line interface, where
 * some simple validation is performed. In the second step the arguments are received at the handler and they can
 * be further validated. </summary>
 *
 * @author WishingBone, TCSDEVELOPER
 * @version 2.0b
 * @since 2.0b
 */
public interface ArgumentHandler {

    /**
     * <summary> This method contract proposes a list of ArgumentOptions to the command line interface. If the
     * instance does not have anything to propose an empty list can be returned. (But to make more sense the entity
     * does not need to implement this interface at the first place.) </summary>
     *
     * @return a list of ArgumentOption instances
     */
    public List proposeOptions();

    /**
     * <summary> This method receives the argument from the command line. The key of the map is the switch name
     * (String) and the value of the map is the argument value (String). If a switch is not included in command
     * line it should not show up in the map. If the switch is included in command line without any follow-up
     * values an empty String ("") is provided as argument value. The interface only receives the arguments it has
     * proposed. </summary>
     *
     * @param arguments the arguments map received
     *
     * @exception NullPointerException if arguments is null
     * @exception IllegalArgumentException if mapped value is not String (while it's not required/necessary to
     * validate the content of the whole map)
     * @exception InvalidArgumentException if some argument is not valid
     */
    public void handleArguments(Map arguments) throws InvalidArgumentException;

}
