/*
 * Copyright (C) 2005 TopCoder Inc., All Rights Reserved.
 *
 * TCS File Statistics 1.0
 */
package com.topcoder.file.statistics.matcher;

import java.io.File;

import com.topcoder.file.statistics.FileMatcher;
import com.topcoder.file.statistics.FileMatchingException;

/**
 * <summary> FileNameMatcher is a template class that handles filename oriented matching logic. </summary>
 *
 * <thread-safety> This class is stateless and thread-safe. </thread-safety>
 *
 * @author WishingBone, TCSDEVELOPER
 * @version 1.0
 */
public abstract class FileNameMatcher implements FileMatcher {

    /**
     * <summary> Default constructor. Does nothing. </summary>
     */
    protected FileNameMatcher() {
        // your code here
    }

    /**
     * <summary> It extracts the filename and calls the template method. </summary>
     *
     * @return whether the file matches
     * @param file the file to match
     *
     * @throws NullPointerException if file is null
     * @throws FileMatchingException if error occurs
     */
    public boolean match(File file) throws FileMatchingException {
        CheckHelper.checkNull(file, "file");
        return match(file.getName());
    }

    /**
     * <summary> Template method to match a filename. </summary>
     *
     * @return whether the filename matches
     * @param filename the filename to match
     *
     * @throws FileMatchingException if error occurs
     */
    protected abstract boolean match(String filename) throws FileMatchingException;
}
