/*
 * Copyright (C) 2005 TopCoder Inc., All Rights Reserved.
 *
 * TCS File Statistics 1.0 (Unit Test)
 */
package com.topcoder.file.statistics;

import junit.framework.TestCase;

import com.topcoder.util.datavalidator.NullValidator;
import com.topcoder.util.datavalidator.ObjectValidator;

/**
 * <p>Unit test case for ArgumentOption class.</p>
 *
 * @author TCSDEVELOPER
 * @version 2.0b
 * @since 2.0b
 */
public class ArgumentOptionTests extends TestCase {

    /** A test switch name string. */
    private static final String SWITCH_NAME = "test switch name";

    /** A test help message string. */
    private static final String HELP_MESSAGE = "test display name";

    /** A test required flag value. */
    private static final boolean REQUIRED = true;

    /** A test validator. */
    private static final ObjectValidator VALIDATOR = new NullValidator();

    /** An argument option used in tests. */
    private static final ArgumentOption ARGUMENT = new ArgumentOption(SWITCH_NAME, HELP_MESSAGE, REQUIRED,
        VALIDATOR);

    /**
     * Creation test for ArgumentOption with valid arguments and no validator.
     */
    public void testArgumentOption1() {
        ArgumentOption arg = new ArgumentOption(SWITCH_NAME, HELP_MESSAGE, REQUIRED);
        assertSame("switch name was not propagated correctly", arg.getSwitchName(), SWITCH_NAME);
        assertSame("help message was not propagated correctly", arg.getHelpMessage(), HELP_MESSAGE);
        assertEquals("required flag was not propagated correctly", arg.isRequired(), REQUIRED);
        assertNull("validator was not set correctly", arg.getValidator());
    }

    /**
     * Creation test for ArgumentOption with valid arguments and a validator.
     */
    public void testArgumentOption2() {
        ArgumentOption arg = new ArgumentOption(SWITCH_NAME, HELP_MESSAGE, REQUIRED, VALIDATOR);
        assertSame("switch name was not propagated correctly", arg.getSwitchName(), SWITCH_NAME);
        assertSame("help message was not propagated correctly", arg.getHelpMessage(), HELP_MESSAGE);
        assertEquals("required flag was not propagated correctly", arg.isRequired(), REQUIRED);
        assertSame("validator was not set correctly", arg.getValidator(), VALIDATOR);
    }

    /**
     * Creation test for ArgumentOption with some null argument. NullPointerException should be thrown.
     */
    public void testArgumentOption3() {
        try {
            new ArgumentOption(null, HELP_MESSAGE, REQUIRED);
            fail("NullPointerException should be thrown.");
        } catch (NullPointerException e) {
            // ok
        }
        try {
            new ArgumentOption(SWITCH_NAME, null, REQUIRED);
            fail("NullPointerException should be thrown.");
        } catch (NullPointerException e) {
            // ok
        }
        try {
            new ArgumentOption(null, HELP_MESSAGE, REQUIRED, VALIDATOR);
            fail("NullPointerException should be thrown.");
        } catch (NullPointerException e) {
            // ok
        }
        try {
            new ArgumentOption(SWITCH_NAME, null, REQUIRED, VALIDATOR);
            fail("NullPointerException should be thrown.");
        } catch (NullPointerException e) {
            // ok
        }
        try {
            new ArgumentOption(SWITCH_NAME, HELP_MESSAGE, REQUIRED, null);
            fail("NullPointerException should be thrown.");
        } catch (NullPointerException e) {
            // ok
        }
    }

    /**
     * Creation test for ArgumentOption with some empty string argument. IllegalArgumentException should be thrown.
     */
    public void testArgumentOption4() {
        try {
            new ArgumentOption(" ", HELP_MESSAGE, REQUIRED);
            fail("NullPointerException should be thrown.");
        } catch (IllegalArgumentException e) {
            // ok
        }
        try {
            new ArgumentOption(SWITCH_NAME, " ", REQUIRED);
            fail("NullPointerException should be thrown.");
        } catch (IllegalArgumentException e) {
            // ok
        }
        try {
            new ArgumentOption(" ", HELP_MESSAGE, REQUIRED, VALIDATOR);
            fail("NullPointerException should be thrown.");
        } catch (IllegalArgumentException e) {
            // ok
        }
        try {
            new ArgumentOption(SWITCH_NAME, " ", REQUIRED, VALIDATOR);
            fail("NullPointerException should be thrown.");
        } catch (IllegalArgumentException e) {
            // ok
        }
    }

    /**
     * Tests getSwitchName getter method.
     */
    public void testGetSwitchName() {
        assertEquals("name was not retrieved properly", ARGUMENT.getSwitchName(), SWITCH_NAME);
    }

    /**
     * Tests getHelpMessage getter method.
     */
    public void testGetHelpMessage() {
        assertEquals("name was not retrieved properly", ARGUMENT.getHelpMessage(), HELP_MESSAGE);
    }

    /**
     * Tests getValidator getter method.
     */
    public void testGetValidator() {
        assertEquals("name was not retrieved properly", ARGUMENT.getValidator(), VALIDATOR);
    }

    /**
     * Tests isRequired getter method.
     */
    public void testIsRequired() {
        assertEquals("name was not retrieved properly", ARGUMENT.isRequired(), REQUIRED);
    }

}
