/*
 * Copyright (C) 2005 TopCoder Inc., All Rights Reserved.
 *
 * TCS File Statistics 1.0 (Unit Test)
 */
package com.topcoder.file.statistics.matcher;

import java.io.File;
import java.io.IOException;

import junit.framework.TestCase;

import com.topcoder.util.config.Property;

/**
 * <p>Unit test case for BinaryFileMatcher class.</p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class BinaryFileMatcherTests extends TestCase {

    /** The matcher instance that is tested. */
    private static final BinaryFileMatcher MATCHER = new BinaryFileMatcher();

    /**
     * Creation test for BinaryFileMatcher default constructor.
     */
    public void testBinaryFileMatcher1() {
        new BinaryFileMatcher();
        // nothing to verify
    }

    /**
     * Creation test for BinaryFileMatcher(Property) with null argument. NullPointerException should be thrown.
     */
    public void testBinaryFileMatcher2() {
        try {
            new BinaryFileMatcher(null);
            fail("NullPointerException should be thrown.");
        } catch (NullPointerException e) {
            // ok
        }
    }

    /**
     * Creation test for BinaryFileMatcher(Property) with valid argument.
     */
    public void testBinaryFileMatcher3() {
        new BinaryFileMatcher(new Property("test property name"));
        // no exception is thrown
    }

    /**
     * Tests match method with null argument. NullPointerException should be thrown.
     *
     * @throws IOException to JUnit
     */
    public void testMatch1() throws IOException {
        try {
            MATCHER.match(null);
            fail("NullPointerException should be thrown.");
        } catch (NullPointerException e) {
            // ok
        }
    }

    /**
     * Tests match(File) method with non-null argument. True should be returned, if the file is binary
     * according to the algorithm of method FileCategoryMatcher.isBinary(File).
     *
     * @throws IOException to JUnit
     */
    public void testMatch2() throws IOException {
        assertTrue("binary file should be matched", MATCHER.match(new File("test_files/a/p.zip")));
        assertFalse("text file should not be matched", MATCHER.match(new File("test_files/a/p.txt")));
        assertFalse("empty file should not be matched", MATCHER.match(new File("test_files/a/empty.txt")));
    }

    /**
     * Tests match(File) method with non-existing file. IOException should be thrown.
     */
    public void testMatch3() {
        try {
            MATCHER.match(new File("test_files/not_exists"));
            fail("IOException should be thrown.");
        } catch (IOException e) {
            // ok
        }
    }

    /**
     * Tests match(File) method with a directory file. IOException should be thrown.
     */
    public void testMatch4() {
        try {
            MATCHER.match(new File("test_files/p/"));
            fail("IOException should be thrown.");
        } catch (IOException e) {
            // ok
        }
    }

    /**
     * Tests match(boolean) method. The argument should be returned straight.
     */
    public void testMatchIsBinary() {
        assertTrue("the argument shoud be returned", MATCHER.match(true));
        assertFalse("the argument shoud be returned", MATCHER.match(false));
    }

}
